@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 from .literals import (
     AccountScopeType,
@@ -252,8 +252,8 @@ AnomalyScoreTypeDef = TypedDict(
 _RequiredAnomalySubscriptionTypeDef = TypedDict(
     "_RequiredAnomalySubscriptionTypeDef",
     {
-        "MonitorArnList": List[str],
-        "Subscribers": List["SubscriberTypeDef"],
+        "MonitorArnList": Sequence[str],
+        "Subscribers": Sequence["SubscriberTypeDef"],
         "Threshold": float,
         "Frequency": AnomalySubscriptionFrequencyType,
         "SubscriptionName": str,
@@ -349,7 +349,7 @@ CostCategorySplitChargeRuleParameterTypeDef = TypedDict(
     "CostCategorySplitChargeRuleParameterTypeDef",
     {
         "Type": Literal["ALLOCATION_PERCENTAGES"],
-        "Values": List[str],
+        "Values": Sequence[str],
     },
 )
 
@@ -357,14 +357,14 @@ _RequiredCostCategorySplitChargeRuleTypeDef = TypedDict(
     "_RequiredCostCategorySplitChargeRuleTypeDef",
     {
         "Source": str,
-        "Targets": List[str],
+        "Targets": Sequence[str],
         "Method": CostCategorySplitChargeMethodType,
     },
 )
 _OptionalCostCategorySplitChargeRuleTypeDef = TypedDict(
     "_OptionalCostCategorySplitChargeRuleTypeDef",
     {
-        "Parameters": List["CostCategorySplitChargeRuleParameterTypeDef"],
+        "Parameters": Sequence["CostCategorySplitChargeRuleParameterTypeDef"],
     },
     total=False,
 )
@@ -406,8 +406,8 @@ CostCategoryValuesTypeDef = TypedDict(
     "CostCategoryValuesTypeDef",
     {
         "Key": str,
-        "Values": List[str],
-        "MatchOptions": List[MatchOptionType],
+        "Values": Sequence[str],
+        "MatchOptions": Sequence[MatchOptionType],
     },
     total=False,
 )
@@ -497,14 +497,14 @@ _RequiredCreateCostCategoryDefinitionRequestRequestTypeDef = TypedDict(
     {
         "Name": str,
         "RuleVersion": Literal["CostCategoryExpression.v1"],
-        "Rules": List["CostCategoryRuleTypeDef"],
+        "Rules": Sequence["CostCategoryRuleTypeDef"],
     },
 )
 _OptionalCreateCostCategoryDefinitionRequestRequestTypeDef = TypedDict(
     "_OptionalCreateCostCategoryDefinitionRequestRequestTypeDef",
     {
         "DefaultValue": str,
-        "SplitChargeRules": List["CostCategorySplitChargeRuleTypeDef"],
+        "SplitChargeRules": Sequence["CostCategorySplitChargeRuleTypeDef"],
     },
     total=False,
 )
@@ -616,8 +616,8 @@ DimensionValuesTypeDef = TypedDict(
     "DimensionValuesTypeDef",
     {
         "Key": DimensionType,
-        "Values": List[str],
-        "MatchOptions": List[MatchOptionType],
+        "Values": Sequence[str],
+        "MatchOptions": Sequence[MatchOptionType],
     },
     total=False,
 )
@@ -733,8 +733,8 @@ ElastiCacheInstanceDetailsTypeDef = TypedDict(
 ExpressionTypeDef = TypedDict(
     "ExpressionTypeDef",
     {
-        "Or": List[Dict[str, Any]],
-        "And": List[Dict[str, Any]],
+        "Or": Sequence[Dict[str, Any]],
+        "And": Sequence[Dict[str, Any]],
         "Not": Dict[str, Any],
         "Dimensions": "DimensionValuesTypeDef",
         "Tags": "TagValuesTypeDef",
@@ -791,7 +791,7 @@ GetAnomaliesResponseTypeDef = TypedDict(
 GetAnomalyMonitorsRequestRequestTypeDef = TypedDict(
     "GetAnomalyMonitorsRequestRequestTypeDef",
     {
-        "MonitorArnList": List[str],
+        "MonitorArnList": Sequence[str],
         "NextPageToken": str,
         "MaxResults": int,
     },
@@ -810,7 +810,7 @@ GetAnomalyMonitorsResponseTypeDef = TypedDict(
 GetAnomalySubscriptionsRequestRequestTypeDef = TypedDict(
     "GetAnomalySubscriptionsRequestRequestTypeDef",
     {
-        "SubscriptionArnList": List[str],
+        "SubscriptionArnList": Sequence[str],
         "MonitorArn": str,
         "NextPageToken": str,
         "MaxResults": int,
@@ -832,14 +832,14 @@ _RequiredGetCostAndUsageRequestRequestTypeDef = TypedDict(
     {
         "TimePeriod": "DateIntervalTypeDef",
         "Granularity": GranularityType,
-        "Metrics": List[str],
+        "Metrics": Sequence[str],
     },
 )
 _OptionalGetCostAndUsageRequestRequestTypeDef = TypedDict(
     "_OptionalGetCostAndUsageRequestRequestTypeDef",
     {
         "Filter": "ExpressionTypeDef",
-        "GroupBy": List["GroupDefinitionTypeDef"],
+        "GroupBy": Sequence["GroupDefinitionTypeDef"],
         "NextPageToken": str,
     },
     total=False,
@@ -874,8 +874,8 @@ _RequiredGetCostAndUsageWithResourcesRequestRequestTypeDef = TypedDict(
 _OptionalGetCostAndUsageWithResourcesRequestRequestTypeDef = TypedDict(
     "_OptionalGetCostAndUsageWithResourcesRequestRequestTypeDef",
     {
-        "Metrics": List[str],
-        "GroupBy": List["GroupDefinitionTypeDef"],
+        "Metrics": Sequence[str],
+        "GroupBy": Sequence["GroupDefinitionTypeDef"],
         "NextPageToken": str,
     },
     total=False,
@@ -912,7 +912,7 @@ _OptionalGetCostCategoriesRequestRequestTypeDef = TypedDict(
         "SearchString": str,
         "CostCategoryName": str,
         "Filter": "ExpressionTypeDef",
-        "SortBy": List["SortDefinitionTypeDef"],
+        "SortBy": Sequence["SortDefinitionTypeDef"],
         "MaxResults": int,
         "NextPageToken": str,
     },
@@ -984,7 +984,7 @@ _OptionalGetDimensionValuesRequestRequestTypeDef = TypedDict(
         "SearchString": str,
         "Context": ContextType,
         "Filter": "ExpressionTypeDef",
-        "SortBy": List["SortDefinitionTypeDef"],
+        "SortBy": Sequence["SortDefinitionTypeDef"],
         "MaxResults": int,
         "NextPageToken": str,
     },
@@ -1019,10 +1019,10 @@ _RequiredGetReservationCoverageRequestRequestTypeDef = TypedDict(
 _OptionalGetReservationCoverageRequestRequestTypeDef = TypedDict(
     "_OptionalGetReservationCoverageRequestRequestTypeDef",
     {
-        "GroupBy": List["GroupDefinitionTypeDef"],
+        "GroupBy": Sequence["GroupDefinitionTypeDef"],
         "Granularity": GranularityType,
         "Filter": "ExpressionTypeDef",
-        "Metrics": List[str],
+        "Metrics": Sequence[str],
         "NextPageToken": str,
         "SortBy": "SortDefinitionTypeDef",
         "MaxResults": int,
@@ -1097,7 +1097,7 @@ _RequiredGetReservationUtilizationRequestRequestTypeDef = TypedDict(
 _OptionalGetReservationUtilizationRequestRequestTypeDef = TypedDict(
     "_OptionalGetReservationUtilizationRequestRequestTypeDef",
     {
-        "GroupBy": List["GroupDefinitionTypeDef"],
+        "GroupBy": Sequence["GroupDefinitionTypeDef"],
         "Granularity": GranularityType,
         "Filter": "ExpressionTypeDef",
         "SortBy": "SortDefinitionTypeDef",
@@ -1171,10 +1171,10 @@ _RequiredGetSavingsPlansCoverageRequestRequestTypeDef = TypedDict(
 _OptionalGetSavingsPlansCoverageRequestRequestTypeDef = TypedDict(
     "_OptionalGetSavingsPlansCoverageRequestRequestTypeDef",
     {
-        "GroupBy": List["GroupDefinitionTypeDef"],
+        "GroupBy": Sequence["GroupDefinitionTypeDef"],
         "Granularity": GranularityType,
         "Filter": "ExpressionTypeDef",
-        "Metrics": List[str],
+        "Metrics": Sequence[str],
         "NextToken": str,
         "MaxResults": int,
         "SortBy": "SortDefinitionTypeDef",
@@ -1247,7 +1247,7 @@ _OptionalGetSavingsPlansUtilizationDetailsRequestRequestTypeDef = TypedDict(
     "_OptionalGetSavingsPlansUtilizationDetailsRequestRequestTypeDef",
     {
         "Filter": "ExpressionTypeDef",
-        "DataType": List[SavingsPlansDataTypeType],
+        "DataType": Sequence[SavingsPlansDataTypeType],
         "NextToken": str,
         "MaxResults": int,
         "SortBy": "SortDefinitionTypeDef",
@@ -1319,7 +1319,7 @@ _OptionalGetTagsRequestRequestTypeDef = TypedDict(
         "SearchString": str,
         "TagKey": str,
         "Filter": "ExpressionTypeDef",
-        "SortBy": List["SortDefinitionTypeDef"],
+        "SortBy": Sequence["SortDefinitionTypeDef"],
         "MaxResults": int,
         "NextPageToken": str,
     },
@@ -1939,8 +1939,8 @@ TagValuesTypeDef = TypedDict(
     "TagValuesTypeDef",
     {
         "Key": str,
-        "Values": List[str],
-        "MatchOptions": List[MatchOptionType],
+        "Values": Sequence[str],
+        "MatchOptions": Sequence[MatchOptionType],
     },
     total=False,
 )
@@ -2031,8 +2031,8 @@ _OptionalUpdateAnomalySubscriptionRequestRequestTypeDef = TypedDict(
     {
         "Threshold": float,
         "Frequency": AnomalySubscriptionFrequencyType,
-        "MonitorArnList": List[str],
-        "Subscribers": List["SubscriberTypeDef"],
+        "MonitorArnList": Sequence[str],
+        "Subscribers": Sequence["SubscriberTypeDef"],
         "SubscriptionName": str,
     },
     total=False,
@@ -2059,14 +2059,14 @@ _RequiredUpdateCostCategoryDefinitionRequestRequestTypeDef = TypedDict(
     {
         "CostCategoryArn": str,
         "RuleVersion": Literal["CostCategoryExpression.v1"],
-        "Rules": List["CostCategoryRuleTypeDef"],
+        "Rules": Sequence["CostCategoryRuleTypeDef"],
     },
 )
 _OptionalUpdateCostCategoryDefinitionRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateCostCategoryDefinitionRequestRequestTypeDef",
     {
         "DefaultValue": str,
-        "SplitChargeRules": List["CostCategorySplitChargeRuleTypeDef"],
+        "SplitChargeRules": Sequence["CostCategorySplitChargeRuleTypeDef"],
     },
     total=False,
 )
